@@ -19,5 +19,5 @@
 
 from .conventional_commits import main
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
