@@ -16,17 +16,14 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import datetime
-import subprocess
 import sys
-from pathlib import Path
-from typing import Callable, Optional, Tuple
+from typing import Optional, Tuple
 
 from packaging.version import InvalidVersion, Version
 
-from pontos import version
-from pontos.git.git import Git
+from pontos.git import Git, GitError
 from pontos.terminal import Terminal
-from pontos.version import CMakeVersionCommand, PythonVersionCommand
+from pontos.version import COMMANDS
 from pontos.version.helper import VersionError
 
 DEFAULT_TIMEOUT = 1000
@@ -34,39 +31,36 @@ DEFAULT_CHUNK_SIZE = 4096
 
 
 def commit_files(
+    git: Git,
     filename: str,
     commit_msg: str,
-    shell_cmd_runner: Callable,
     *,
     git_signing_key: str = "",
     changelog: bool = False,
-):
+) -> None:
     """Add files to staged and commit staged files.
 
-    filename: The filename of file to add and commit
-    commit_msg: The commit message for the commit
-    shell_cmd_runner: The runner for shell commands
-    git_signing_key: The signing key to sign this commit
+    Args:
+        git: A Git instance
+        filename: The filename of file to add and commit
+        commit_msg: The commit message for the commit
+        git_signing_key: The signing key to sign this commit
+        changelog: Add CHANGELOG.md file
 
-    Arguments:
-        to: The version (str) that will be set
-        develop: Wether to set version to develop or not (bool)
-
-    Returns:
-       executed: True if successfully executed, False else
-       filename: The filename of the project definition
     """
+    git.add(filename)
+
+    try:
+        git.add("*__version__.py")
+    except GitError:
+        pass
 
-    shell_cmd_runner(f"git add {filename}")
-    shell_cmd_runner("git add *__version__.py || echo 'ignoring __version__'")
     if changelog:
-        shell_cmd_runner("git add CHANGELOG.md")
+        git.add("CHANGELOG.md")
     if git_signing_key:
-        shell_cmd_runner(
-            f"git commit -S{git_signing_key} --no-verify -m '{commit_msg}'",
-        )
+        git.commit(commit_msg, verify=False, gpg_signing_key=git_signing_key)
     else:
-        shell_cmd_runner(f"git commit --no-verify -m '{commit_msg}'")
+        git.commit(commit_msg, verify=False)
 
 
 def calculate_calendar_version(terminal: Terminal) -> str:
@@ -109,23 +103,18 @@ def calculate_calendar_version(terminal: Terminal) -> str:
         sys.exit(1)
 
 
-def get_current_version(terminal: Terminal) -> str:
+def get_current_version(terminal: Terminal) -> Optional[str]:
     """Get the current Version from a pyproject.toml or
     a CMakeLists.txt file"""
 
-    available_cmds = [
-        ("CMakeLists.txt", CMakeVersionCommand),
-        ("pyproject.toml", PythonVersionCommand),
-    ]
-    for file_name, cmd in available_cmds:
-        project_definition_path = Path.cwd() / file_name
-        if project_definition_path.exists():
-            terminal.ok(f"Found {file_name} project definition file.")
-            current_version: str = cmd().get_current_version()
-            return current_version
+    for cmd in COMMANDS:
+        command = cmd()
+        if command.project_found():
+            terminal.ok("Found project definition file.")
+            return command.get_current_version()
 
     terminal.error("No project settings file found")
-    sys.exit(1)
+    return None
 
 
 def get_last_release_version() -> Optional[str]:
@@ -178,52 +167,46 @@ def get_next_dev_version(release_version: str) -> str:
         raise (VersionError(e)) from None
 
 
-def get_project_name(
-    shell_cmd_runner: Callable,
-    *,
+def get_git_repository_name(
     remote: str = "origin",
 ) -> str:
     """Get the git repository name
 
     Arguments:
-        shell_cmd_runner: The runner for shell commands
         remote: the remote to look up the name (str) default: origin
 
     Returns:
         project name
     """
-    ret = shell_cmd_runner(f"git remote get-url {remote}")
-    return ret.stdout.split("/")[-1].replace(".git", "").strip()
+
+    ret = Git().remote_url(remote)
+    return ret.rsplit("/", maxsplit=1)[-1].replace(".git", "").strip()
 
 
-def find_signing_key(terminal: Terminal, shell_cmd_runner: Callable) -> str:
+def find_signing_key(terminal: Terminal) -> str:
     """Find the signing key in the config
 
     Arguments:
-        shell_cmd_runner: The runner for shell commands
+        terminal: The terminal for console output
 
     Returns:
         git signing key or empty string
     """
 
     try:
-        proc = shell_cmd_runner("git config user.signingkey")
-    except subprocess.CalledProcessError as e:
+        return Git().config("user.signingkey").strip()
+    except GitError as e:
         # The command `git config user.signingkey` returns
         # return code 1 if no key is set.
         # So we will return empty string ...
         if e.returncode == 1:
             terminal.warning("No signing key found.")
         return ""
-    # stdout should return "\n" if no key is available
-    # and so git_signing_key should
-    # return '' if no key is available ...
-    return proc.stdout.strip()
 
 
 def update_version(
     terminal: Terminal, to: str, *, develop: bool = False
-) -> Tuple[bool, str]:
+) -> Tuple[bool, Optional[str]]:
     """Use pontos-version to update the version.
 
     Arguments:
@@ -234,17 +217,20 @@ def update_version(
        executed: True if successfully executed, False else
        filename: The filename of the project definition
     """
-    args = ["--quiet"]
-    args.append("update")
-    args.append(to)
-    if develop:
-        args.append("--develop")
-    executed, filename = version.main(leave=False, args=args)
+    project_file = None
+    for cmd in COMMANDS:
+        command = cmd()
+        project_file = command.project_file_found()
+        if project_file:
+            break
 
-    if not executed:
-        if filename == "":
-            terminal.error("No project definition found.")
-        else:
-            terminal.error(f"Unable to update version {to} in {filename}")
+    if not project_file:
+        terminal.error("No project definition found.")
+        return False, None
 
-    return executed, filename
+    try:
+        command.update_version(new_version=to, develop=develop)
+        return True, project_file.name
+    except VersionError:
+        terminal.error(f"Unable to update version {to} in {project_file}")
+        return False, None
